@@ -1,5 +1,6 @@
-/*
- * Copyright (C) 1999, 2002, 2003, 2004  Free Software Foundation, Inc.
+/* 
+ * Copyright (C) 1999, 2002, 2003, 2004, 2005 Free Software Foundation,
+ * Inc.
  * 
  * This file is part of GNU libmatheval
  * 
@@ -23,7 +24,7 @@
 double
 math_cot(double x)
 {
-	/*
+	/* 
 	 * Calculate cotangent value.
 	 */
 	return 1 / tan(x);
@@ -32,7 +33,7 @@ math_cot(double x)
 double
 math_sec(double x)
 {
-	/*
+	/* 
 	 * Calculate secant value.
 	 */
 	return 1 / cos(x);
@@ -41,7 +42,7 @@ math_sec(double x)
 double
 math_csc(double x)
 {
-	/*
+	/* 
 	 * Calculate cosecant value.
 	 */
 	return 1 / sin(x);
@@ -50,7 +51,7 @@ math_csc(double x)
 double
 math_acot(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse cotangent value.
 	 */
 	return atan(1 / x);
@@ -59,7 +60,7 @@ math_acot(double x)
 double
 math_asec(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse secant value.
 	 */
 	return acos(1 / x);
@@ -68,16 +69,16 @@ math_asec(double x)
 double
 math_acsc(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse cosecant value.
 	 */
-	return asin (1 / x);
+	return asin(1 / x);
 }
 
 double
 math_coth(double x)
 {
-	/*
+	/* 
 	 * Calculate hyperbolic cotangent value.
 	 */
 	return 1 / tanh(x);
@@ -86,7 +87,7 @@ math_coth(double x)
 double
 math_sech(double x)
 {
-	/*
+	/* 
 	 * Calculate hyperbolic secant value.
 	 */
 	return 1 / cosh(x);
@@ -95,7 +96,7 @@ math_sech(double x)
 double
 math_csch(double x)
 {
-	/*
+	/* 
 	 * Calculate hyperbolic cosecant value.
 	 */
 	return 1 / sinh(x);
@@ -104,7 +105,7 @@ math_csch(double x)
 double
 math_asinh(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse hyperbolic sine value.
 	 */
 	return log(x + sqrt(x * x + 1));
@@ -113,7 +114,7 @@ math_asinh(double x)
 double
 math_acosh(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse hyperbolic cosine value.
 	 */
 	return log(x + sqrt(x * x - 1));
@@ -122,7 +123,7 @@ math_acosh(double x)
 double
 math_atanh(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse hyperbolic tangent value.
 	 */
 	return 0.5 * log((1 + x) / (1 - x));
@@ -131,7 +132,7 @@ math_atanh(double x)
 double
 math_acoth(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse hyperbolic cotangent value.
 	 */
 	return 0.5 * log((x + 1) / (x - 1));
@@ -140,7 +141,7 @@ math_acoth(double x)
 double
 math_asech(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse hyperbolic secant value.
 	 */
 	return math_acosh(1 / x);
@@ -149,32 +150,35 @@ math_asech(double x)
 double
 math_acsch(double x)
 {
-	/*
+	/* 
 	 * Calculate inverse hyperbolic cosecant value.
 	 */
-        return math_asinh(1 / x);
+	return math_asinh(1 / x);
 }
 
-double          math_step(double x)
+double
+math_step(double x)
 {
-        /*
+	/* 
 	 * Calculate step function value.
 	 */
-        return (x < 0) ? 0 : 1;
+	return (x < 0) ? 0 : 1;
 }
 
-double          math_delta(double x)
+double
+math_delta(double x)
 {
-        /*
+	/* 
 	 * Calculate delta function value.
 	 */
-        return (x == 0) ? MATH_INFINITY : 0;
+	return (x == 0) ? MATH_INFINITY : 0;
 }
 
-double          math_nandelta(double x)
+double
+math_nandelta(double x)
 {
-        /*
+	/* 
 	 * Calculate modified delta function value.
 	 */
-        return (x == 0) ? MATH_NAN : 0;
+	return (x == 0) ? MATH_NAN : 0;
 }
